@@ -58,7 +58,7 @@ use Math::Symbolic::Derivative qw//;
 
 use base 'Math::Symbolic::Base';
 
-our $VERSION = '0.604';
+our $VERSION = '0.605';
 
 =head1 CLASS DATA
 
@@ -835,7 +835,7 @@ sub simplify {
                 }
                 my $mul = Math::Symbolic::Operator->new(
                     '*',
-                    Math::Symbolic::Constant->new($num),
+                    Math::Symbolic::Constant->new(abs($num)),
                     Math::Symbolic::Variable->new($_)
                 );
                 push @ops, $num < 0
